@@ -2,12 +2,14 @@
 """Bashrc Package."""
 import os
 import pathlib
+import shutil
 from importlib.metadata import version as __version__
 from typing import Text, Literal
 
 import distro
 import typer
 
+command = 'rc'
 Int = bool
 
 app = typer.Typer()
@@ -82,9 +84,9 @@ def secrets():
     """Secrets Update."""
     global dist
     if dist == 'darwin':
-        os.system(f'secrets_push.sh')
+        os.system(f'secrets-push.sh')
     elif dist == 'Kali':
-        os.system(f'secrets_pull.sh')
+        os.system(f'secrets-pull.sh')
 
 
 @app.command()
@@ -97,21 +99,19 @@ def up(bump: Text = Option.option(Option.Function.__args__[0], 'Part of version
     """
     global dist
     if dist == 'darwin':
-        os.system(f'bashrc.upload.sh {bump} && rebash')
+        os.system(f'{command} --version && bashrc-upload.sh {bump} && {command} --version  && source ~/.bashrc')
     elif dist == 'Kali':
-        os.system(f'bashrc.upgrade.sh && rebash')
+        os.system(f'{command} --version && bashrc-upgrade.sh && {command} --version && source ~/.bashrc')
 
 
 def version_callback(value: bool):
     if value:
-        typer.echo(f"rc [{package.name}]: {__version__(package.name)}")
+        typer.echo(f"{__version__(package.name)}")
         raise typer.Exit()
 
 
 # noinspection PyUnusedLocal
 @app.callback()
-def main(
-    version: bool = typer.Option(None, "--version", callback=version_callback, is_eager=True),
-):
+def main(version: bool = typer.Option(None, "--version", callback=version_callback, is_eager=True)):
     # Do other global stuff, handle other global options here
     return
